@@ -2,5 +2,7 @@ from .client import MoonlistClient
 from .exceptions import *
 from .http import ApiClient
 from .webhook_manager import *
+from . import models
 from .models.api import *
-from .models.webhooks import *
\ No newline at end of file
+from .models.webhooks import *
+from .models.bases import *
\ No newline at end of file
